
# q-expansion of newform 833.2.g.h, downloaded from the LMFDB on 05 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 833
weight = 2
poly_data = [49, 0, 3504, 0, 22464, 0, 53872, 0, 61088, 0, 38162, 0, 14160, 0, 3200, 0, 432, 0, 32, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[3136, 0, 67732, 0, 126696, 0, 162101, 0, 149616, 0, 77120, 0, 21540, 0, 3272, 0, 255, 0, 8, 0], 17038], [[0, -528268, 0, -5447519, 0, -16613221, 0, -17246325, 0, -8223353, 0, -1913400, 0, -172299, 0, 9847, 0, 2963, 0, 155], 102228], [[0, -360980, 0, -1447304, 0, -3302745, 0, -3760016, 0, -2365248, 0, -884700, 0, -201528, 0, -27393, 0, -2040, 0, -64], 34076], [[0, -156524, 0, -1311000, 0, -3285707, 0, -3760016, 0, -2365248, 0, -884700, 0, -201528, 0, -27393, 0, -2040, 0, -64], 17038], [[0, 1452241, 0, 2253575, 0, -10192559, 0, -21274722, 0, -16804000, 0, -7070883, 0, -1731417, 0, -247495, 0, -19154, 0, -620], 102228], [[-19873, 0, 2523601, 0, 13697567, 0, 22903158, 0, 17834923, 0, 7537923, 0, 1839897, 0, 259675, 0, 19706, 0, 623, 0], 102228], [[214382, 1452071, 3579541, 9771637, 15091379, 26865854, 27146727, 36785367, 23096809, 27010681, 10511406, 11340183, 2721477, 2809101, 402187, 405838, 31607, 31607, 1025, 1025], 204456], [[-214382, 1452071, -3579541, 9771637, -15091379, 26865854, -27146727, 36785367, -23096809, 27010681, -10511406, 11340183, -2721477, 2809101, -402187, 405838, -31607, 31607, -1025, 1025], 204456], [[22141, -450487, -1876765, -4609046, -14315015, -23201815, -24849489, -37868541, -19781710, -29867879, -8681763, -13119783, -2225277, -3372870, -331111, -503879, -26465, -40477, -878, -1351], 204456], [[-22141, -450487, 1876765, -4609046, 14315015, -23201815, 24849489, -37868541, 19781710, -29867879, 8681763, -13119783, 2225277, -3372870, 331111, -503879, 26465, -40477, 878, -1351], 204456], [[229733, -1291333, 5099876, -2655655, 18809419, 5832481, 24120397, 15309952, 15438195, 13260099, 5648861, 5917003, 1239156, 1507601, 161395, 221369, 11517, 17440, 347, 571], 68152], [[-229733, -1291333, -5099876, -2655655, -18809419, 5832481, -24120397, 15309952, -15438195, 13260099, -5648861, 5917003, -1239156, 1507601, -161395, 221369, -11517, 17440, -347, 571], 68152], [[-181153, -2409442, 4702942, -27803546, 21451967, -92180911, 24854010, -122165610, 12532834, -83411435, 2998023, -32724786, 256974, -7674162, -23345, -1062791, -5926, -80170, -310, -2539], 204456], [[-181153, 2409442, 4702942, 27803546, 21451967, 92180911, 24854010, 122165610, 12532834, 83411435, 2998023, 32724786, 256974, 7674162, -23345, 1062791, -5926, 80170, -310, 2539], 204456], [[31899, 0, 1343175, 0, 3206880, 0, 103148, 0, -2827987, 0, -2121741, 0, -699961, 0, -120516, 0, -10584, 0, -375, 0], 34076], [[287875, 0, 7726742, 0, 32247646, 0, 48175983, 0, 36065927, 0, 15311163, 0, 3848214, 0, 566426, 0, 45067, 0, 1495, 0], 102228], [[121037, 0, -7624514, 0, -32247646, 0, -48175983, 0, -36065927, 0, -15311163, 0, -3848214, 0, -566426, 0, -45067, 0, -1495, 0], 102228], [[0, 2285519, 0, 28804033, 0, 88289351, 0, 110542500, 0, 72672256, 0, 27840963, 0, 6438849, 0, 885295, 0, 66584, 0, 2108], 102228]]

hecke_ring_character_values = [[52, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [785, [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 1, 0, -2, -1, 1, 0, 0, 0, 2, 0, 1, -1, 0, 1, 0, 0, -1], [0, 2, 0, 0, 0, 2, 2, 0, 0, 0, -1, -1, 0, 0, 1, -1, 0, 0, 0, 0], [0, -1, 1, 0, 0, 0, -1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1], [0, 0, 0, -1, -1, -1, 1, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1, 1, 0, 0], [1, 0, 0, 1, 1, 0, 1, 0, -2, 0, 0, 0, 0, 1, 1, 1, -1, 1, -1, -1], [0, -1, -1, 1, 0, 0, 0, 1, -2, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0], [3, 0, 0, -1, -1, 2, 1, 0, 0, 2, 0, 0, 0, 0, 1, 2, -1, -1, -1, 1], [0, 0, 0, 0, 1, 2, 1, 0, 0, 0, -2, -2, -1, -1, -1, 1, 0, 0, 0, 0], [-2, 0, 2, 0, 0, 0, 0, -2, -1, 1, 1, -1, -1, 1, 1, 1, 0, 0, 2, 0], [0, 2, 0, -3, -1, -3, 0, 0, 0, 0, 1, 1, 2, 2, 2, -2, 0, 0, 0, -1], [0, 0, 0, 0, 0, -2, -2, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0], [3, -2, 2, 1, -1, 2, -1, -2, 0, 0, 0, 0, -2, 0, 1, 2, -1, 1, -1, 1], [2, 0, -2, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 3, 3, -3, 0, -1, 0], [-1, 1, 1, -1, 2, 3, 2, -3, -2, 0, 0, -2, 0, 0, 0, 2, -2, 2, 2, 2], [-1, 0, 0, 1, -1, 0, -1, 2, 2, 0, 0, 2, 0, 0, -2, -1, 1, -1, 1, 1], [3, 0, 0, 1, -1, 2, 1, -2, 0, 0, 0, 0, -4, 0, 1, 1, -1, -1, 0, 0], [0, 0, 0, -2, 2, 2, 2, 0, -1, -1, 0, 0, 0, 0, -1, 1, 0, 0, 0, 2], [-6, 0, 2, 0, 0, 0, 0, -2, 1, -1, 1, -1, 1, -1, -2, -2, 0, 2, 2, 0], [2, 0, 0, 2, 2, 0, -2, 0, -2, 0, 0, -2, 0, -1, 2, 2, -2, -2, -2, -2], [-4, 0, 2, 0, 0, 0, 0, -4, 0, 0, 3, -3, 3, -3, 2, 2, -4, 2, 0, 0], [-4, 0, -4, 0, 0, 0, 0, 2, 1, -1, 0, 0, 1, -1, -2, -2, 0, 2, 2, 0], [-4, 1, 1, 0, 1, 5, 3, -1, 2, 0, 0, -2, 0, -2, -1, 1, -1, 3, 2, 2], [-4, 2, -2, -2, 1, -3, -1, 3, 0, 0, 0, 0, 2, 0, -1, -1, 1, 1, 0, 0], [0, 0, 0, 0, -2, -2, 1, -2, 0, 4, 2, 0, 0, 0, 2, 4, -2, -1, -1, 1], [0, -2, 0, -1, -1, -7, -4, 0, 2, 2, 1, 1, 2, 2, 0, 0, 0, 0, 0, -1], [0, 2, 2, -2, 0, 0, 2, -2, -2, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0], [-1, 0, -4, 0, 0, 0, 0, -3, 2, -2, -2, 2, -1, 1, -2, -2, 1, -3, 2, 0], [-7, -2, -2, 1, 1, 8, -1, 0, 2, 0, 0, 0, 0, -3, -5, 1, -1, -1, 3, 3], [-1, 0, 0, 0, 0, 0, 0, -3, -2, 2, 2, -2, 1, -1, 0, 0, -3, -1, 0, 0], [0, -2, 0, 2, 1, -4, -3, 0, 2, 2, 2, 2, 1, 1, -1, 1, 0, 0, 0, -4], [-2, 0, -2, 0, 0, 0, 0, 2, 1, -1, -3, 3, 0, 0, 1, 1, 2, -2, -4, 0], [1, -1, 1, 1, 1, 2, -2, 0, 0, -2, -4, 0, -4, 0, -1, -1, 1, 2, 1, -1], [4, 2, 2, 2, 0, -4, 2, 2, 0, 0, 0, 4, 0, 2, -1, 0, 0, 2, -2, -2], [3, -6, -6, 1, -1, -4, -3, 2, 2, 0, 0, 2, 0, 2, -2, -1, 1, -3, -1, -1], [0, 0, 0, 2, -3, -12, -1, 0, -2, -2, 4, 4, 3, 3, 1, -1, 0, 0, 0, -2], [-3, 0, 0, 3, 1, -2, -3, -2, 0, -2, 4, 0, 0, 0, -1, 1, 1, 3, 1, -1], [0, 0, 0, 0, 0, 0, 0, 0, 2, -2, -1, 1, 0, 0, -1, -1, 5, 0, 3, 0], [2, -3, 3, 3, -3, -1, -4, -6, 0, 2, 4, 0, 0, 0, 3, 3, -3, 4, 1, -1], [-9, 3, -3, 1, 2, -7, 1, 1, 0, -6, 0, 0, 4, 0, -2, -4, 2, -1, 3, -3], [6, -2, -2, 0, 0, -6, 2, 0, -2, 0, 0, 0, 0, 0, -1, 0, 0, 2, 2, 2], [4, -2, 2, -1, 1, 5, 2, 2, 0, 4, -2, 0, -2, 0, -1, 5, 1, -2, -3, 3], [0, 2, 0, 4, -2, -4, 2, 0, 2, 2, 3, 3, 1, 1, 2, -2, 0, 0, 0, 0], [5, 2, -2, 1, -1, 4, -1, -2, 0, -2, 2, 0, -1, 0, 1, 3, -1, 1, 3, -3], [0, 2, 0, -6, -2, -4, -2, 0, -1, -1, 1, 1, 3, 3, 1, -1, 0, 0, 0, 2], [-1, -1, -1, 2, 0, 1, -1, 2, 6, 0, 0, 0, 0, 0, -2, 0, 0, -1, -3, -3], [5, 0, 4, 0, 0, 0, 0, -3, 2, -2, 0, 0, 1, -1, -2, -2, -1, -1, -2, 0], [6, 4, 4, -2, 2, -4, 2, -4, 0, 0, 0, 0, 0, 1, 2, 2, -2, 2, 2, 2], [-4, 0, -2, 0, 0, 0, 0, -4, 2, -2, 1, -1, -1, 1, -1, -1, 0, 0, 0, 0], [0, 10, 0, -4, -2, -4, 0, 0, 0, 0, 1, 1, 2, 2, 3, -3, 0, 0, 0, -4], [0, 0, 0, -2, 4, 4, 4, 0, 0, 0, -2, -2, 0, 0, -4, 4, 0, 0, 0, 4], [-3, -2, -2, 1, -1, 2, -5, 2, 4, 0, 0, 2, 0, -4, -5, -1, 1, -5, -1, -1], [8, 0, -10, 0, 0, 0, 0, 4, -2, 2, -3, 3, -1, 1, 0, 0, 0, -4, 0, 0], [5, 1, 1, 0, 0, -5, -3, 0, -2, 0, 0, 0, 0, 2, 2, 0, 0, -3, -1, -1], [0, 0, 0, 1, 3, 5, -2, 0, -2, -2, -1, -1, 0, 0, -2, 2, 0, 0, 0, 5], [1, 2, -2, -3, -1, 0, 5, 2, 0, 0, -2, 0, 1, 0, 1, -5, -1, -5, -3, 3], [0, 0, -2, 0, 0, 0, 0, -2, -2, 2, 1, -1, 1, -1, 1, 1, -2, -2, 4, 0], [-6, 0, 4, 0, 0, 0, 0, 4, 3, -3, 0, 0, 1, -1, -4, -4, 4, 0, 0, 0], [1, 0, 0, -1, 3, 2, 1, -4, -4, 0, 0, -6, 0, -1, 1, 3, -3, 1, -1, -1], [-6, 6, -6, 0, 0, -6, 4, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, -4, 2, -2], [3, 1, -1, -3, -5, -2, -1, -2, 0, 2, 6, 0, 6, 0, 5, 1, -5, 1, 0, 0], [0, 8, 0, -7, -1, 1, 6, 0, 2, 2, -1, -1, 0, 0, 2, -2, 0, 0, 0, 1], [1, 0, 0, 4, 4, 3, 2, 0, -4, 0, 0, -4, 0, -2, 2, 4, -4, 2, -2, -2], [2, 4, -4, -2, 0, 2, 6, 2, 0, 4, -4, 0, -2, 0, 0, -2, 0, -6, -2, 2], [0, 0, 0, 0, 2, 10, 4, 0, 1, 1, -4, -4, -3, -3, -2, 2, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, 0, 2, 1, -1, 3, -3, 3, -3, -4, -4, 0, 0, -2, 0], [0, 8, 0, -3, 7, 7, 8, 0, -2, -2, -5, -5, 2, 2, 4, -4, 0, 0, 0, -1], [0, -2, 2, -4, 6, 6, 2, 10, 0, -6, -10, 0, -2, 0, -6, -7, 6, -2, -4, 4], [9, 0, -6, 0, 0, 0, 0, 5, 4, -4, -2, 2, -1, 1, -4, -4, -1, -7, 0, 0], [-4, 2, 2, -4, 1, 5, 6, -5, -4, 0, 0, -6, 0, -2, 5, 1, -1, 6, 1, 1], [0, 2, 0, 0, -4, -14, -4, 0, 5, 5, -1, -1, 0, 0, 0, 0, 0, 0, 0, -4], [0, 0, 0, -1, -3, 13, 6, 0, -2, -2, -1, -1, 0, 0, 4, -4, 0, 0, 0, -1], [2, -6, 6, 2, -2, 0, -4, -4, 0, 2, 6, 0, -1, 0, 2, 4, -2, 4, 0, 0], [-2, -5, 5, 6, 5, 3, 0, -1, 0, -6, 4, 0, -2, 0, -5, 1, 5, 0, -1, 1], [6, 0, -4, 0, 0, 0, 0, 8, 2, -2, -2, 2, -2, 2, 2, 2, -2, -4, -2, 0], [7, 4, -4, -3, -5, 2, 3, -2, 0, 2, 2, 0, 1, 0, 5, -3, -5, -3, 1, -1], [-1, 0, -6, 0, 0, 0, 0, -3, 2, -2, 0, 0, -1, 1, 2, 2, -1, -1, 6, 0], [1, -1, 1, 1, -3, -2, -4, -4, 0, -2, 8, 0, 2, 0, 3, 3, -3, 4, 5, -5], [0, 10, 0, -6, 4, 12, 4, 0, -5, -5, -5, -5, -1, -1, -3, 3, 0, 0, 0, 2], [-6, 2, 2, 0, 6, 12, 2, -6, -8, 0, 0, -6, 0, -8, 3, 6, -6, 2, 0, 0], [-8, 0, -2, 0, 0, 0, 0, 4, 0, 0, 2, -2, 2, -2, -2, -2, 2, -2, 4, 0], [2, -5, 5, -1, -1, 1, -4, 0, 0, -2, 0, 0, -2, 0, 1, 3, -1, 4, 1, -1], [0, 0, 0, 3, 5, -7, 2, 0, -4, -4, 1, 1, 4, 4, 4, -4, 0, 0, 0, 3], [0, 2, 0, 0, 4, 10, -2, 0, -3, -3, -7, -7, -2, -2, -2, 2, 0, 0, 0, 0], [-9, 0, -4, 0, 0, 0, 0, -7, 0, 0, 4, -4, 1, -1, 2, 2, -5, 1, 0, 0], [0, 2, 0, -4, 2, 4, 4, 0, 5, 5, -5, -5, -3, -3, 2, -2, 0, 0, 0, 4], [2, 0, 0, -6, -4, -6, 2, -2, 0, 0, 0, 0, 0, 0, -3, -4, 4, 2, 4, 4], [-2, 1, -1, -4, -1, -3, 3, 3, 0, -2, -2, 0, 2, 0, 1, -11, -1, -3, 0, 0], [0, 2, 0, -5, -5, 5, -4, 0, 4, 4, -3, -3, -2, -2, 2, -2, 0, 0, 0, -1], [5, -5, 5, -7, 1, 6, 2, 8, 0, 2, -8, 0, -6, 0, -1, -1, 1, -2, -5, 5], [7, -4, 4, 1, -1, 6, 3, -2, 0, 2, 2, 0, -3, 0, 1, 5, -1, -3, -5, 5], [12, 0, -4, 0, 0, 0, 0, 0, -3, 3, 2, -2, -1, 1, -3, -3, -4, -4, -4, 0], [-19, -2, 2, -1, -1, -20, -3, 0, 0, 0, 8, 0, 8, 0, 1, 0, -1, 3, 3, -3], [6, 0, 6, 0, 0, 0, 0, -8, 0, 0, 3, -3, -2, 2, 4, 4, 0, 2, 0, 0], [3, -1, -1, 3, 3, 0, 3, 0, -6, 0, 0, 2, 0, -4, -7, 3, -3, 3, -2, -2], [-2, 6, 6, 2, 1, 3, 0, 1, -4, 0, 0, -6, 0, -4, 3, 1, -1, 0, 1, 1], [8, 0, 6, 0, 0, 0, 0, 2, -4, 4, -6, 6, -6, 6, 0, 0, 2, 6, 0, 0], [0, -2, 0, 4, 0, 8, 2, 0, 3, 3, -1, -1, -1, -1, 4, -4, 0, 0, 0, -4], [0, 2, 0, -6, -11, 0, -3, 0, 6, 6, 6, 6, -1, -1, -1, 1, 0, 0, 0, 4], [-5, -3, 3, 3, 2, -3, -6, -1, 0, 6, -2, 0, 4, 0, -2, 0, 2, 6, 2, -2], [0, 0, 4, 0, 0, 0, 0, -2, -1, 1, -4, 4, -7, 7, 0, 0, 4, 0, -6, 0], [0, -6, 0, 4, 0, 8, -2, 0, 3, 3, -3, -3, -3, -3, -1, 1, 0, 0, 0, 4], [0, -2, 0, 4, -4, 2, -8, 0, 4, 4, 5, 5, 0, 0, 4, -4, 0, 0, 0, 0], [-1, 0, 2, 0, 0, 0, 0, -13, 0, 0, 2, -2, -3, 3, 10, 10, -7, -1, 0, 0], [-9, -6, 6, 3, 3, -6, 1, 0, 0, -4, 4, 0, 6, 0, -3, -3, 3, -1, 5, -5], [-5, 2, 2, -3, 3, 8, 1, -6, 2, 0, 0, -4, 0, -1, -5, 3, -3, 1, 3, 3], [4, 0, -8, 0, 0, 0, 0, -2, -8, 8, 1, -1, -2, 2, 1, 1, -1, -6, -1, 0], [5, 0, 0, 2, -5, -10, -8, 7, 8, 0, 0, 6, 0, 0, -11, -5, 5, -8, -5, -5], [2, 2, -2, 0, 4, 6, 2, 4, 0, 4, -8, 0, 0, 0, -4, -4, 4, -2, -2, 2], [0, 2, 0, 1, 1, -13, 0, 0, -2, -2, 5, 5, 6, 6, -2, 2, 0, 0, 0, -7], [-9, 5, 5, -6, -5, 4, 1, -1, 2, 0, 0, -6, 0, 0, 1, -5, 5, 1, 4, 4], [8, 2, 2, -4, 2, -6, 2, -6, -6, 0, 0, -2, 0, 12, 5, 2, -2, 2, 0, 0], [0, 0, 6, 0, 0, 0, 0, -8, -1, 1, 3, -3, 3, -3, 4, 4, -4, 6, 4, 0], [-3, -4, 4, -1, 1, -2, -8, 2, 0, 0, -2, 0, -2, 0, -1, 3, 1, 8, -1, 1], [-2, 0, -6, 0, 0, 0, 0, 4, 0, 0, -3, 3, -6, 6, -1, -1, 5, -4, -1, 0], [0, 6, 0, 2, 2, 0, -8, 0, -2, -2, -1, -1, 2, 2, -1, 1, 0, 0, 0, -10], [0, -6, 6, 2, -4, -4, -3, -6, 0, -4, 10, 0, 2, 0, 4, 8, -4, 3, -3, 3], [-7, 0, 0, 9, -1, 6, -5, 10, -2, 0, 0, 0, 0, 0, -7, -1, 1, -5, -5, -5], [0, -3, -3, 0, 5, 5, 3, -5, -2, 0, 0, -2, 0, 4, 1, 5, -5, 3, 4, 4], [-10, 0, 0, 2, 4, -6, 2, 2, 0, -4, 0, 0, 2, 0, -4, 1, 4, -2, 4, -4], [2, 0, -2, 0, 0, 0, 0, 16, -4, 4, -6, 6, 0, 0, -4, -4, 2, -4, -14, 0], [-10, -1, -1, 4, 0, 10, -4, 4, -2, 0, 0, 2, 0, 2, 0, 0, 0, -4, 2, 2], [-2, -2, -2, 2, 2, 4, 6, 0, -6, 0, 0, 4, 0, 4, -1, 2, -2, 6, 4, 4], [12, 0, -12, 0, 0, 0, 0, 2, -5, 5, -6, 6, -3, 3, -3, -3, -2, -14, -4, 0], [0, -6, 0, -4, 4, 6, -6, 0, 3, 3, 3, 3, 4, 4, -6, 6, 0, 0, 0, 0], [0, -8, 0, 4, -1, -10, -1, 0, -2, -2, 2, 2, -7, -7, -3, 3, 0, 0, 0, -4], [9, -4, -4, 5, 0, -9, -3, 5, 8, 0, 0, 6, 0, -2, -12, 0, 0, -3, 1, 1], [-10, 1, 1, -3, -3, 7, -1, 0, 2, 0, 0, -2, 0, -6, -1, -3, 3, -1, 0, 0], [0, -8, 0, 6, 7, 4, -1, 0, 0, 0, 0, 0, 3, 3, -3, 3, 0, 0, 0, 0], [2, 0, -4, 0, 0, 0, 0, -2, 6, -6, -2, 2, 0, 0, -2, -2, -4, 0, 6, 0], [-8, 0, -2, 0, 0, 0, 0, -12, -3, 3, 7, -7, 5, -5, 12, 12, -6, 12, 6, 0], [0, 6, 0, -4, 0, 10, 2, 0, -3, -3, 1, 1, -1, -1, -7, 7, 0, 0, 0, 8], [-4, 6, 6, -4, 2, 6, 0, -6, -4, 0, 0, -4, 0, -2, 6, 2, -2, 0, 4, 4], [0, 8, 0, -6, -4, -18, 2, 0, -3, -3, 2, 2, 2, 2, 5, -5, 0, 0, 0, -2], [8, 5, -5, -2, 0, 8, 4, 2, 0, -10, 2, 0, 0, 0, 0, -10, 0, -4, -2, 2], [-8, -8, -8, 2, 2, 10, 0, 0, 8, 0, 0, -4, 0, -8, 1, 2, -2, 0, 2, 2], [-4, 5, 5, 2, 5, 9, 6, -3, -10, 0, 0, -4, 0, 4, 13, 5, -5, 6, -1, -1], [-1, 6, -6, -4, -3, -4, -1, 1, 0, -4, 0, 0, 4, 0, 3, -1, -3, 1, -2, 2], [-4, 3, -3, -3, 0, -4, -7, 3, 0, -2, -4, 0, 0, 0, 0, 0, 0, 7, -1, 1], [10, 0, 0, 0, 0, 0, 0, 10, 1, -1, -8, 8, -5, 5, -5, -5, 4, 6, -2, 0], [-10, -4, 4, -4, 0, -10, 0, 4, 0, 6, -2, 0, -2, 0, 0, 4, 0, 0, -4, 4], [9, 2, 2, 5, -3, -12, -3, 8, 2, 0, 0, 6, 0, -2, 1, -3, 3, -3, -9, -9], [16, -4, 4, -2, -8, 8, -2, -6, 0, 8, 0, 0, -3, 0, 8, 12, -8, 2, -4, 4], [0, 2, 0, 6, 4, 6, 0, 0, -7, -7, -3, -3, -3, -3, -1, 1, 0, 0, 0, 6], [-14, 0, -10, 0, 0, 0, 0, 6, 0, 0, -1, 1, 2, -2, -1, -1, 5, 8, 3, 0], [2, 7, -7, -7, 1, 3, 4, 8, 0, -2, -4, 0, 6, 0, -1, -3, 1, -4, 1, -1], [-14, -2, -2, 4, -4, 10, -2, 8, 8, 0, 0, 0, 0, -5, 0, -4, 4, -2, 0, 0], [-22, 0, 2, 0, 0, 0, 0, -2, 4, -4, 3, -3, 0, 0, -5, -5, 3, 4, 1, 0], [1, 2, 2, 7, 1, 0, 3, 6, 4, 0, 0, -2, 0, -7, -1, 1, -1, 3, -3, -3], [11, 6, -6, -4, 3, 14, 5, 7, 0, -4, -8, 0, -12, 0, -3, -1, 3, -5, -2, 2], [-7, -1, 1, 0, -1, -8, -4, -1, 0, 2, 0, 0, 0, 0, 1, -3, -1, 4, -5, 5], [-11, 0, 10, 0, 0, 0, 0, 1, -6, 6, -2, 2, 3, -3, -2, -2, -1, 9, 4, 0], [2, -4, 4, 8, -4, -2, -2, -12, 0, 4, 14, 0, -1, 0, 4, 6, -4, 2, -4, 4], [0, -4, 0, -8, 2, -8, -8, 0, 2, 2, 0, 0, -6, -6, -4, 4, 0, 0, 0, 8], [1, -6, 6, 5, 9, 10, 3, 4, 0, 0, -2, 0, 2, 0, -9, 2, 9, -3, 1, -1], [-5, -6, -6, -4, 0, 5, -1, -4, 4, 0, 0, -2, 0, -4, -12, 0, 0, -1, -1, -1], [0, 0, 2, 0, 0, 0, 0, 8, -2, 2, -3, 3, 0, 0, -1, -1, 5, 6, 1, 0], [0, 8, 0, 8, 3, -6, -5, 0, -4, -4, 4, 4, 1, 1, 1, -1, 0, 0, 0, -12], [0, -6, 0, 12, -10, -2, 2, 0, 5, 5, 1, 1, -6, -6, -1, 1, 0, 0, 0, -4], [0, -2, 0, -3, -7, -11, 2, 0, 0, 0, -1, -1, 6, 6, 2, -2, 0, 0, 0, 3], [-11, 4, 4, -7, -1, 10, 7, -6, 4, 0, 0, -8, 0, -1, 1, -1, 1, 7, 3, 3], [8, 0, 0, 1, 7, -1, -6, -6, -4, 0, 0, -6, 0, 0, 9, 7, -7, -6, -1, -1], [1, 2, -2, -3, -5, -4, 1, -2, 0, 4, 4, 0, -6, 0, 5, 2, -5, -1, -5, 5]]
